pub struct LabelKeyInfo {
pub profile_public_keys: Vec<Vec<u8>>,
pub network_id: Option<String>,
}Expand description
Determines how an envelope key should be encrypted for a given label. Information required to perform envelope encryption for a label.
Fields
profile_public_keys: Vec<Vec<u8>>network_id: Option<String>Trait Implementations
Sourceimpl Clone for LabelKeyInfo
impl Clone for LabelKeyInfo
Sourcefn clone(&self) -> LabelKeyInfo
fn clone(&self) -> LabelKeyInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LabelKeyInfo
impl Debug for LabelKeyInfo
Sourceimpl<'de> Deserialize<'de> for LabelKeyInfo
impl<'de> Deserialize<'de> for LabelKeyInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more